# sales_analyzer123

## Описание

Это Python-пакет, который помогает быстро и легко анализировать данные о продажах, полученные из CSV-файла.

## Установка и использование

```bash
pip install sales_analyzer123